pub struct LayoutStack { /* private fields */ }Expand description
A vertical layout stack that tracks the current row and produces panels for each component drawn.
Compositors create a stack at a starting row, then call draw
for each component in order. The stack advances the row by the number
of rows each component consumed.
Implementations
Sourceimpl LayoutStack
impl LayoutStack
pub fn new( start_row: u16, terminal_width: u16, box_column: u16, box_width: u16, ) -> Self
pub fn row(&self) -> u16
pub fn terminal_width(&self) -> u16